;; Generated package description from vundo.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "vundo" "2.4.0.0.20250314.193537" "Visual undo tree" '((emacs "28.1")) :commit "b89f719824fe5da0f6a7590fad3ece798fd59909" :authors '(("Yuan Fu" . "casouri@gmail.com")) :maintainer '("Yuan Fu" . "casouri@gmail.com") :keywords '("undo" "text" "editing") :url "https://github.com/casouri/vundo")
